@@ -323,7 +323,8 @@ Rsq <- function(object, type = c("Cox Snell","Cragg Uhler","both"))
   type <- match.arg(type)
   if (!is.gamlss(object)) stop("this is design for gamlss objects only")
   #  m0 <- update(object,  formula=~1, sigma.formula=~1, nu.formula=~1, tau.formula=~1, trace=F)
-  suppressWarnings(m0 <- gamlssML(object$y, family=object$family))
+  Y <- if (object$family[1]%in%.gamlss.bi.list) cbind(object$y, object$bd-object$y) else object$y
+  suppressWarnings(m0 <- gamlssML(Y~1, family=object$family[1]))
   rsq1 <- 1-exp((2/object$N)*(logLik(m0)[1]-logLik(object)[1]))
   rsq2 <- rsq1/(1-exp((2/object$N)*logLik(m0)[1]))
   if (type=="Cox Snell") return(rsq1)
